@@ -1384,7 +1384,6 @@ class Client(commandServer, encrypt, Desktop):
         """
         Синхронизация профиля пользователя
         """
-        execStr = ""
         rsyncopts = list(rsyncopts)
         skipPaths = self.clVars.Get("cl_sync_skip_path")
         if not skipPaths:
@@ -1431,14 +1430,12 @@ class Client(commandServer, encrypt, Desktop):
             for i in ps.sync("%s/"%source, "%s/"%target, *rsyncParams):
                 self.setProgress(i)
 
-            pathConfig = os.path.join(userHome,
-                                      self.pathConfig)
-            
+            configFileName = os.path.join(remoteProfile, self.configFileDesktop)
             try:
-                if iniParser(pathConfig).setVar(
-                        'rsync', {'exitcode': rsync.getExitCode()}):
-                    os.chmod(pathConfig, 0o600)
-                    os.chown(pathConfig, uid, gid)
+                if iniParser(configFileName).setVar(
+                        'rsync', {'exitcode': ps.exitstatus}):
+                    os.chmod(configFileName, 0o600)
+                    os.chown(configFileName, uid, gid)
             except Exception:
                 pass
             if ps.exitstatus != 0:
